@@ -67,14 +67,13 @@ cTelnet::cTelnet( Host * pH )
 , mpComposer( 0 )
 
 {
-
     mIsTimerPosting = false;
     mNeedDecompression = false;
     mWaitingForCompressedStreamToStart = false;
     // initialize default encoding
     encoding = "UTF-8";
     encodingChanged(encoding);
-    termType = "Mudlet 2.0.1";
+    termType = "Mudlet 2.1.0";
     iac = iac2 = insb = false;
 
     command = "";
@@ -235,6 +234,10 @@ void cTelnet::handle_socket_signal_connected()
 void cTelnet::handle_socket_signal_disconnected()
 {
     postData();
+    TEvent me;
+    me.mArgumentList.append( "sysDisconnectionEvent" );
+    me.mArgumentTypeList.append( ARGUMENT_TYPE_STRING );
+    mpHost->raiseEvent( &me );
     QString msg;
     QTime timeDiff(0,0,0,0);
     msg = QString("[ INFO ]  -  connection time: %1\n").arg(timeDiff.addMSecs(mConnectionTime.elapsed()).toString("hh:mm:ss.zzz"));
@@ -452,7 +455,7 @@ void cTelnet::processTelnetCommand( const string & command )
   case 254: _type = "DONT"; break;
   default: _type = QString::number((quint8)ch);
   };
-  qDebug()<<"SERVER send telnet signal:"<<_type<<" + "<<(quint8)command[2];
+  qDebug()<<"SERVER sends telnet signal:"<<_type<<" + "<<(quint8)command[2];
 #endif
 
   char option;
@@ -512,27 +515,11 @@ void cTelnet::processTelnetCommand( const string & command )
               _h = TN_IAC;
               _h += TN_SB;
               _h += GMCP;
-              _h += "Core.Supports.Set [ \"Char 1\", \"Char.Skills 1\", \"Char.Items 1\", \"Room 1\", \"IRE.Composer 1\"]";
+              _h += "Core.Supports.Set [ \"Char 1\", \"Char.Skills 1\", \"Char.Items 1\", \"Room 1\", \"IRE.Rift 1\", \"IRE.Composer 1\"]";
               _h += TN_IAC;
               _h += TN_SE;
 
               socketOutRaw( _h );
-
-              /*if ((mpHost->getLogin().size()>0) && (mpHost->getPass().size()>0)) {
-                _h = TN_IAC;
-                _h += TN_SB;
-                _h += GMCP;
-                _h += "Char.Login { \"name\": \"";
-                _h += mpHost->getLogin().toLatin1().data();
-                _h += "\", \"password\": \"";
-                _h += mpHost->getPass().toLatin1().data();
-                _h += "\" }";
-                _h += TN_IAC;
-                _h += TN_SE;
-
-                cout << "  sending: " << _h << endl;
-                socketOutRaw( _h );
-              }*/
               break;
           }
 
@@ -610,6 +597,11 @@ void cTelnet::processTelnetCommand( const string & command )
                            }
                        }
                    }
+                   else if( supportedTelnetOptions.contains( option ) )
+                   {
+                       sendTelnetOption( TN_DO, option );
+                       hisOptionState[idxOption] = true;
+                   }
                    else
                    {
                        sendTelnetOption( TN_DONT, option );
@@ -617,6 +609,8 @@ void cTelnet::processTelnetCommand( const string & command )
                    }
                }
           }
+
+
           break;
       }
 
@@ -734,7 +728,7 @@ void cTelnet::processTelnetCommand( const string & command )
           }
           if( option == OPT_NAWS )
           {
-                                        //NAWS
+              //NAWS
               setDisplayDimensions();
           }
           break;
@@ -828,7 +822,6 @@ void cTelnet::processTelnetCommand( const string & command )
                   mpProgressDialog->show();
 
               }
-
               return;
           }
 
@@ -839,7 +832,6 @@ void cTelnet::processTelnetCommand( const string & command )
               if( command.size() < 6 ) return;
               _m = _m.mid( 3, command.size()-5 );
               setGMCPVariables( _m );
-
               return;
           }
 
@@ -919,6 +911,25 @@ void cTelnet::processTelnetCommand( const string & command )
           //other commands are simply ignored (NOP and such, see .h file for list)
       }
   };//end switch 1
+  // raise sysTelnetEvent for all unhandled protocols
+  // EXCEPT TN_GA (performance)
+  if( command[1] != TN_GA )
+  {
+      unsigned char type = static_cast<unsigned char>(command[1]);
+      unsigned char telnetOption = static_cast<unsigned char>(command[2]);
+      QString msg = command.c_str();
+      if( command.size() >= 6 ) msg = msg.mid( 3, command.size()-5 );
+      TEvent me;
+      me.mArgumentList.append( "sysTelnetEvent" );
+      me.mArgumentTypeList.append( ARGUMENT_TYPE_STRING );
+      me.mArgumentList.append( QString::number(type) );
+      me.mArgumentTypeList.append( ARGUMENT_TYPE_NUMBER );
+      me.mArgumentList.append( QString::number(telnetOption) );
+      me.mArgumentTypeList.append( ARGUMENT_TYPE_NUMBER );
+      me.mArgumentList.append( msg );
+      me.mArgumentTypeList.append( ARGUMENT_TYPE_STRING );
+      mpHost->raiseEvent( &me );
+  }
 }
 
 void cTelnet::setATCPVariables( QString & msg )
