@@ -210,6 +210,7 @@ void dlgPackageExporter::slot_export_package(){
     } else {
         ui->infoLabel->setText("Failed to export - couldn't open "+filePath+" for writing in. Do you have the necessary permissions to write to that folder?");
     }
+    close();
 }
 
 void dlgPackageExporter::slot_addFiles(){
@@ -264,6 +265,7 @@ void dlgPackageExporter::listTriggers()
     for(it = tList.begin(); it != tList.end(); it++)
     {
         TTrigger * pChild = *it;
+        if( pChild->isTempTrigger() ) continue;
         QStringList sl;
         sl << pChild->getName();
         QTreeWidgetItem * pItem = new QTreeWidgetItem(sl);
@@ -305,6 +307,8 @@ void dlgPackageExporter::listAliases()
     for(it = tList.begin(); it != tList.end(); it++)
     {
         TAlias * pChild = *it;
+        if (pChild->isTempAlias())
+            continue;
         QStringList sl;
         sl << pChild->getName();
         QTreeWidgetItem * pItem = new QTreeWidgetItem(sl);
@@ -463,6 +467,8 @@ void dlgPackageExporter::listTimers()
     for(it = tList.begin(); it != tList.end(); it++)
     {
         TTimer * pChild = *it;
+        if (pChild->isTempTimer())
+            continue;
         QStringList sl;
         sl << pChild->getName();
         QTreeWidgetItem * pItem = new QTreeWidgetItem(sl);
